@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2007 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Martin Gasbichler, Mike Sperber, Robert Ransom
 
 ; Type lattice.
 ; Sorry this is so hairy, but before it was written, type checking 
@@ -163,7 +165,7 @@
 
 (define (make-optional-type t)
   (if (type-more t)
-      (warn "peculiar type in make-optional-type" t))
+      (warning 'make-optional-type "peculiar type in make-optional-type" t))
   (make-type (bitwise-ior (type-mask t) mask/no-values)
 	     #f
 	     (type-info t)))
@@ -199,7 +201,7 @@
 (define (tail-type t)
   (if (empty-rail-type? t)
       ;; bottom-type   ?
-      (warn "rail-type of empty rail" t))
+      (warning 'tail-type "rail-type of empty rail" t))
   (let ((more (type-more t)))
     (if more
 	(cdr more)
@@ -329,7 +331,7 @@
 ;
 ; (+ (f 1) (car (f 'a)))    [reconstructing type of f by computing meet of all contexts]
 ;   => meet (proc (:integer) :number nonr) (proc (:symbol) :pair nonr)
-;   => (proc ((join :integer :symbol) (join :number :pair)) nonr), yes?
+;   => (proc ((join :integer :symbol)) (join :number :pair) nonr), yes?
 ;
 ; 2. If both types are restrictive, we need to MEET both domains and
 ; codomains.
@@ -453,7 +455,7 @@
 		    ((> (bitwise-and m mask/procedure) 0)
 		     (join-procedure m t1 t2))
 		    (else
-		     (error "This shouldn't happen" t1 t2))))))))
+		     (assertion-violation 'join-type "This shouldn't happen" t1 t2))))))))
 
 (define (join-rail t1 t2)
   (let ((t (join-type (head-type t1) (head-type t2))))
@@ -621,8 +623,8 @@
 	    (mask->type (cadr x)))
            ((variable)
             (variable-type (sexp->type (cadr x) r?)))
-	   (else (error "unrecognized type" x))))
-	(else (error "unrecognized type" x))))
+	   (else (assertion-violation 'sexp->type "unrecognized type" x))))
+	(else (assertion-violation 'sexp->type "unrecognized type" x))))
 
 (define (sexp->values-type l req? r?)
   (cond ((null? l)
@@ -774,13 +776,13 @@
        (i 0 (+ i 1)))
       ((empty-rail-type? d) i)
     (if (optional-type? d)
-	(error "this shouldn't happen" t d))))
+	(assertion-violation 'procedure-type-arity "this shouldn't happen" t d))))
 
 (define (procedure-type-argument-types t)
   (let recur ((d (procedure-type-domain t)))
     (cond ((empty-rail-type? d) '())
 	  ((optional-type? d)
-	   (call-error "lossage" procedure-type-argument-types t))
+	   (assertion-violation 'procedure-type-argument-types "lossage" t))
 	  (else
 	   (cons (head-type d)
 		 (recur (tail-type d)))))))
